==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Visual/analyzer/translations/analyzer_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="36"/>
        <source>Qmmp Analyzer</source>
        <translation>Analisador Qmmp</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="323"/>
        <source>Peaks</source>
        <translation>Picos</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="326"/>
        <source>Refresh Rate</source>
        <translation>Taxa de atualização</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="329"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="330"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="331"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="332"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="339"/>
        <source>Analyzer Falloff</source>
        <translation>Solução para analisador</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="342"/>
        <location filename="../analyzer.cpp" line="356"/>
        <source>Slowest</source>
        <translation>Mais lenta</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="343"/>
        <location filename="../analyzer.cpp" line="357"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="344"/>
        <location filename="../analyzer.cpp" line="358"/>
        <source>Medium</source>
        <translation>Média</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="345"/>
        <location filename="../analyzer.cpp" line="359"/>
        <source>Fast</source>
        <translation>Rápida</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="346"/>
        <location filename="../analyzer.cpp" line="360"/>
        <source>Fastest</source>
        <translation>Mais rápida</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="353"/>
        <source>Peaks Falloff</source>
        <translation>Solução para picos</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="367"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="367"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation>Selecione a cor</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation>Tamanho das células:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation>Cores</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation>Picos:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation>Analisador #1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation>Fundo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation>Analisador #2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation>Analisador #3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Suplemento Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Acerca de suplemento Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Suplemento Qmmp Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp-1.7.3.tar.bz2: qmmp-1.7.3/src/plugins/Visual/analyzer/translations/analyzer_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="36"/>
        <source>Qmmp Analyzer</source>
        <translation>Analisador Qmmp</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="312"/>
        <source>Peaks</source>
        <translation>Picos</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="315"/>
        <source>Refresh Rate</source>
        <translation>Taxa de atualização</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="318"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="319"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="320"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="321"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="328"/>
        <source>Analyzer Falloff</source>
        <translation>Solução para analisador</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="331"/>
        <location filename="../analyzer.cpp" line="345"/>
        <source>Slowest</source>
        <translation>Mais lenta</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="332"/>
        <location filename="../analyzer.cpp" line="346"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="333"/>
        <location filename="../analyzer.cpp" line="347"/>
        <source>Medium</source>
        <translation>Média</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="334"/>
        <location filename="../analyzer.cpp" line="348"/>
        <source>Fast</source>
        <translation>Rápida</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="335"/>
        <location filename="../analyzer.cpp" line="349"/>
        <source>Fastest</source>
        <translation>Mais rápida</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="342"/>
        <source>Peaks Falloff</source>
        <translation>Solução para picos</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="356"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="356"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>AnalyzerColorWidget</name>
    <message>
        <location filename="../analyzercolorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation>Selecionar cor</translation>
    </message>
</context>
<context>
    <name>AnalyzerSettingsDialog</name>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="35"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation>Tamanho das células:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation>Cores</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation>Picos:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation>Analisador #1:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation>Fundo:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation>Analisador #2:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation>Analisador #3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Suplemento Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Acerca de suplemento Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Suplemento Qmmp Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
